import fastapi
from pydantic import BaseModel


router = fastapi.APIRouter(prefix='/api')

words = [
    {"id": 1, "name": "Баг"}, {"id": 2, "name": "Задача"}, {"id": 3, "name": "Тикет"}, {"id": 4, "name": "Приоритет"},
    {"id": 5, "name": "Отчёт об ошибке"}
]


class Task(BaseModel):
    name: str


@router.get('/tasks')
async def tasks():
    return words


@router.get('/tasks/{id_}')
async def get_task(id_: int):
    for word in words:
        if word['id'] == id_:
            return word
    return {"error": "Задача не найдена"}


@router.post('/tasks')
async def create_task(task: Task):
    id_ = len(words) + 1
    task = {"id": id_, "name": task.name}
    words.append(task)
    return task


@router.put('/tasks/{id_}')
async def update_task(id_: int, task: Task):
    for word in words:
        if word['id'] == id_:
            word['name'] = task.name
            return word

    return {"error": "Задача не найдена"}

app = fastapi.FastAPI()
app.include_router(router)


if __name__ == '__main__':
    import uvicorn

    uvicorn.run('main:app', host='localhost', port=8000, reload=True)
